@@ -57,3 +57,33 @@ cran_version <- function(x = packageVersion("worcs")){
   )
 }
 
+
+all_args <- function(orig_values = FALSE, ...) {
+  # Perhaps ... must be removed altogether, see https://github.com/HenrikBengtsson/future/issues/13
+  # get formals for parent function
+  parent_formals <- formals(sys.function(sys.parent(n = 1)))
+
+  # Get names of implied arguments
+  fnames <- names(parent_formals)
+
+  # Remove '...' from list of parameter names if it exists
+  fnames <- fnames[-which(fnames == '...')]
+
+  # Get currently set values for named variables in the parent frame
+  args <- evalq(as.list(environment()), envir = parent.frame())
+
+  # Get the list of variables defined in '...'
+  # CJ: This needs to be fixed to work with nested function calls
+  args <- c(args[fnames], evalq(list(...), envir = parent.frame()))
+
+
+  if(orig_values) {
+    # get default values
+    defargs <- as.list(parent_formals)
+    defargs <- defargs[unlist(lapply(defargs, FUN = function(x) class(x) != "name"))]
+    args[names(defargs)] <- defargs
+    setargs <- evalq(as.list(match.call())[-1], envir = parent.frame())
+    args[names(setargs)] <- setargs
+  }
+  return(args)
+}
